@@ -423,7 +423,7 @@ function update_option( $option, $value, $autoload = null ) {
  * @return bool False if option was not added and true if option was added.
  */
 function add_option( $option, $value = '', $deprecated = '', $autoload = 'yes' ) {
-	global $wpdb;
+//	global $wpdb;
 
 	if ( !empty( $deprecated ) )
 		_deprecated_argument( __FUNCTION__, '2.3.0' );
@@ -439,15 +439,22 @@ function add_option( $option, $value = '', $deprecated = '', $autoload = 'yes' )
 
 	$value = sanitize_option( $option, $value );
 
+	// #################################################################################################################
+	// ###### オプション値がMagic3側で初期化(コンテンツAPIマネージャーのloadPlugin())されている場合は上書きしない ######
+	// #################################################################################################################
 	// Make sure the option doesn't already exist. We can check the 'notoptions' cache before we ask for a db query
-	$notoptions = wp_cache_get( 'notoptions', 'options' );
-	if ( !is_array( $notoptions ) || !isset( $notoptions[$option] ) )
-		/** This filter is documented in wp-includes/option.php */
-		if ( apply_filters( 'default_option_' . $option, false, $option, false ) !== get_option( $option ) )
-			return false;
+//	$notoptions = wp_cache_get( 'notoptions', 'options' );
+//	if ( !is_array( $notoptions ) || !isset( $notoptions[$option] ) ){
+//		/** This filter is documented in wp-includes/option.php */
+		if ( apply_filters( 'default_option_' . $option, false, $option, false ) !== get_option( $option ) ) return false;
+//	}
 
 	$serialized_value = maybe_serialize( $value );
 	$autoload = ( 'no' === $autoload || false === $autoload ) ? 'no' : 'yes';
+	
+	// 初期値を設定
+	global $m3WpOptions;		// 初期値取得用
+	$m3WpOptions[$option] = $value;
 
 	/**
 	 * Fires before an option is added.
@@ -457,13 +464,13 @@ function add_option( $option, $value = '', $deprecated = '', $autoload = 'yes' )
 	 * @param string $option Name of the option to add.
 	 * @param mixed  $value  Value of the option.
 	 */
-	do_action( 'add_option', $option, $value );
+//	do_action( 'add_option', $option, $value );
 
 /*	$result = $wpdb->query( $wpdb->prepare( "INSERT INTO `$wpdb->options` (`option_name`, `option_value`, `autoload`) VALUES (%s, %s, %s) ON DUPLICATE KEY UPDATE `option_name` = VALUES(`option_name`), `option_value` = VALUES(`option_value`), `autoload` = VALUES(`autoload`)", $option, $serialized_value, $autoload ) );
 	if ( ! $result )
 		return false;*/
 
-	if ( ! wp_installing() ) {
+/*	if ( ! wp_installing() ) {
 		if ( 'yes' == $autoload ) {
 			$alloptions = wp_load_alloptions();
 			$alloptions[ $option ] = $serialized_value;
@@ -471,14 +478,14 @@ function add_option( $option, $value = '', $deprecated = '', $autoload = 'yes' )
 		} else {
 			wp_cache_set( $option, $serialized_value, 'options' );
 		}
-	}
+	}*/
 
 	// This option exists now
-	$notoptions = wp_cache_get( 'notoptions', 'options' ); // yes, again... we need it to be fresh
+/*	$notoptions = wp_cache_get( 'notoptions', 'options' ); // yes, again... we need it to be fresh
 	if ( is_array( $notoptions ) && isset( $notoptions[$option] ) ) {
 		unset( $notoptions[$option] );
 		wp_cache_set( 'notoptions', $notoptions, 'options' );
-	}
+	}*/
 
 	/**
 	 * Fires after a specific option has been added.
@@ -491,7 +498,7 @@ function add_option( $option, $value = '', $deprecated = '', $autoload = 'yes' )
 	 * @param string $option Name of the option to add.
 	 * @param mixed  $value  Value of the option.
 	 */
-	do_action( "add_option_{$option}", $option, $value );
+//	do_action( "add_option_{$option}", $option, $value );
 
 	/**
 	 * Fires after an option has been added.
@@ -501,7 +508,7 @@ function add_option( $option, $value = '', $deprecated = '', $autoload = 'yes' )
 	 * @param string $option Name of the added option.
 	 * @param mixed  $value  Value of the option.
 	 */
-	do_action( 'added_option', $option, $value );
+//	do_action( 'added_option', $option, $value );
 	return true;
 }
 
