@@ -587,7 +587,12 @@ qq.extend(qq.FileUploader.prototype, {
             if ( ! relatedTarget || relatedTarget.nodeName == "HTML"){               
                 dropArea.style.display = 'none';                                            
             }
-        });                
+        });
+		qq.attach(document, 'drop', function(e){	// add by naoki on 2013/2/1
+			dropArea.style.display = 'none';
+
+			e.preventDefault();
+		});
     },
     _onSubmit: function(id, fileName){
         qq.FileUploaderBasic.prototype._onSubmit.apply(this, arguments);
@@ -1062,9 +1067,10 @@ qq.extend(qq.UploadHandlerForm.prototype, {
         
         this.log("converting iframe's innerHTML to JSON");
         this.log("innerHTML = " + doc.body.innerHTML);
-                        
+
         try {
-            response = eval("(" + doc.body.innerHTML + ")");
+            //response = eval("(" + doc.body.innerHTML + ")");
+			response = jQuery.parseJSON(doc.body.textContent || doc.body.innerText);	// need parse JSON data in IE. modified by naoki on 2013/2/1
         } catch(err){
             response = {};
         }        
