@@ -8,21 +8,24 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2016 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 
 class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetContainer
 {
+	protected $_mainDb;			// DB接続オブジェクト
 	const BREADCRUMB_TITLE	= 'システム情報';		// パンくずリストトップタイトル
 	// 画面
 	const TASK_CONFIGSYS		= 'configsys';	// システム基本設定
 	const TASK_CONFIGLANG		= 'configlang';	// 言語設定
 	const TASK_CONFIGMESSAGE	= 'configmessage';	// メッセージ設定
 	const TASK_CONFIGIMAGE		= 'configimage';		// 画像設定
+	const TASK_CONFIGMAIL		= 'configmail';			// メールサーバ
 	const TASK_SERVER_ENV		= 'serverenv';	// サーバ環境
 	const DEFAULT_TASK			= 'configsys';		// デフォルト画面
 	
@@ -33,6 +36,9 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
+		
+		// DB接続オブジェクト作成
+		$this->_mainDb = new admin_mainDb();
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -67,6 +73,9 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 			case self::TASK_CONFIGIMAGE:		// 画像設定
 				$titles[] = $this->_('Image Cofiguration');
 				break;
+			case self::TASK_CONFIGMAIL:		// メールサーバ
+				$titles[] = $this->_('Mail Server Cofiguration');
+				break;
 		}
 		$this->gPage->setAdminBreadcrumbDef($titles);
 				
@@ -112,6 +121,15 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 									'help'		=> $this->gInstance->getHelpManager()->getHelpText(self::TASK_CONFIGIMAGE),// ヘルプ文字列
 									'submenu'	=> array()
 								),
+								(Object)array(
+									'name'		=> $this->_('Mail Server Cofiguration'),		// メールサーバ
+									'task'		=> self::TASK_CONFIGMAIL,
+									'url'		=> '',
+									'tagid'		=> '',
+									'active'	=> ($task == self::TASK_CONFIGMAIL),
+									'help'		=> $this->gInstance->getHelpManager()->getHelpText(self::TASK_CONFIGMAIL),// ヘルプ文字列
+									'submenu'	=> array()
+								),
 								(Object)array(
 									'name'		=> $this->_('Server Environment'),			// サーバ環境
 									'task'		=> self::TASK_SERVER_ENV,
